==> ckeditor5_premium_features-1.2.6.tar.gz: ckeditor5_premium_features/modules/ckeditor5_premium_features_realtime_collaboration/js/ckeditor5_plugins/realtimeRevisionHistoryAdapter/src/realtimeRevisionHistoryAdapter.js <==
/*
 * Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see https://ckeditor.com/legal/ckeditor-oss-license
 */

import CollaborationStorage
  from "../../../../../../js/ckeditor5_plugins/collaborationStorage/src/collaborationStorage";


class RealtimeRevisionHistoryAdapter {
  constructor( editor ) {
    this.editor = editor;
    this.storage = new CollaborationStorage(editor);
  }

  static get pluginName() {
    return 'RealtimeRevisionHistoryAdapter'
  }

  static get requires() {
    return ['RevisionTracker']
  }

  afterInit() {
    this.elementId = this.editor.sourceElement.dataset.ckeditor5PremiumElementId;
    const revisionHistoryConfig = this.editor.config._config.revisionHistory;

    revisionHistoryConfig.viewerContainer = document.querySelector(`.revision-history-container-data[data-ckeditor5-premium-element-id="${this.elementId}"]`);
    revisionHistoryConfig.viewerEditorElement = revisionHistoryConfig.viewerContainer.querySelector('.revision-viewer-editor');
    revisionHistoryConfig.viewerSidebarContainer = revisionHistoryConfig.viewerContainer.querySelector('.revision-viewer-sidebar');
    revisionHistoryConfig.editorContainer = revisionHistoryConfig.viewerContainer.parentElement.querySelector('.ck-editor-premium-wrapper').parentElement;

    // Initialize plugin.
    const revisionHistoryPlugin = this.editor.plugins.get('RevisionHistory');
    const revisionTrackerPlugin = this.editor.plugins.get('RevisionTracker');

    // Hook to form submit.
    const form = this.editor.sourceElement.closest('form');
    form.addEventListener("submit", (e) => {
      this.updateStorage(revisionHistoryPlugin, revisionTrackerPlugin)
    });

    this.storage.processRevisionDisable();

    this.copyEditorVisibilityToFilterSelector(revisionHistoryConfig);
  }

  async updateStorage(plugin, tracker) {
    await tracker.update();
    await tracker.saveRevision({name: 'Entity save'});
  }

  copyEditorVisibilityToFilterSelector(revisionHistoryConfig) {
    const filterElement = revisionHistoryConfig.editorContainer.parentElement.querySelector(".js-filter-wrapper")
    var observer = new IntersectionObserver(function(entries) {
      if(entries[0]['intersectionRatio'] == 0) {
        filterElement.style.display = "none";
      }
      else {
        filterElement.style.display = "block";
      }
    }, { root: document.documentElement });

    if (filterElement) {
      observer.observe(revisionHistoryConfig.editorContainer);
    }
  }

}

export default RealtimeRevisionHistoryAdapter;

==> ckeditor5_premium_features-1.3.0.tar.gz: ckeditor5_premium_features/modules/ckeditor5_premium_features_realtime_collaboration/js/ckeditor5_plugins/realtimeRevisionHistoryAdapter/src/realtimeRevisionHistoryAdapter.js <==
/*
 * Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see https://ckeditor.com/legal/ckeditor-oss-license
 */

import CollaborationStorage
  from "../../../../../../js/ckeditor5_plugins/collaborationStorage/src/collaborationStorage";


class RealtimeRevisionHistoryAdapter {
  constructor( editor ) {
    this.editor = editor;
    this.storage = new CollaborationStorage(editor);
  }

  static get pluginName() {
    return 'RealtimeRevisionHistoryAdapter'
  }

  static get requires() {
    return ['RevisionTracker']
  }

  afterInit() {
    this.elementId = this.editor.sourceElement.dataset.ckeditor5PremiumElementId;
    const revisionHistoryConfig = this.editor.config._config.revisionHistory;

    revisionHistoryConfig.viewerContainer = document.querySelector(`.revision-history-container-data[data-ckeditor5-premium-element-id="${this.elementId}"]`);
    revisionHistoryConfig.viewerEditorElement = revisionHistoryConfig.viewerContainer.querySelector('.revision-viewer-editor');
    revisionHistoryConfig.viewerSidebarContainer = revisionHistoryConfig.viewerContainer.querySelector('.revision-viewer-sidebar');
    revisionHistoryConfig.editorContainer = revisionHistoryConfig.viewerContainer.parentElement.querySelector('.ck-editor-premium-wrapper').parentElement;

    // Initialize plugin.
    const revisionHistoryPlugin = this.editor.plugins.get('RevisionHistory');
    const revisionTrackerPlugin = this.editor.plugins.get('RevisionTracker');

    // Hook to form submit.
    const form = this.editor.sourceElement.closest('form');
    form.addEventListener("submit", (e) => {
      this.updateStorage(revisionHistoryPlugin, revisionTrackerPlugin)
    });

    this.storage.processRevisionDisable();

    this.handleRevisionHistoryActiveClass(revisionHistoryConfig);
  }

  async updateStorage(plugin, tracker) {
    await tracker.update();
    await tracker.saveRevision({name: 'Entity save'});
  }

  handleRevisionHistoryActiveClass(revisionHistoryConfig) {
    var observer = new IntersectionObserver(function(entries) {
      if(entries[0]['intersectionRatio'] == 0) {
        revisionHistoryConfig.editorContainer.parentElement.classList.add('revision-history-active');
      }
      else {
        revisionHistoryConfig.editorContainer.parentElement.classList.remove('revision-history-active');
      }
    }, { root: document.documentElement });

    observer.observe(revisionHistoryConfig.editorContainer);
  }

}

export default RealtimeRevisionHistoryAdapter;
